@@ -47,7 +47,7 @@ class MainTransformer(object):
 
     def transform(self):
         if not self._namespace.names:
-            message.fatal('Namespace is empty; likely causes are:\n'
+            message.error('Namespace is empty; likely causes are:\n'
                           '* Not including .h files to be scanned\n'
                           '* Broken --identifier-prefix')
 
@@ -176,6 +176,16 @@ class MainTransformer(object):
         block = self._blocks.get(node.symbol)
         self._apply_annotations_callable(node, chain, block)
 
+    def _apply_annotations_function_macro(self, node, chain):
+        block = self._blocks.get(node.symbol)
+        for param in node.parameters:
+            if block:
+                doc_param = block.params.get(param.argname)
+                if doc_param:
+                    param.doc = doc_param.description
+                    param.doc_position = doc_param.position
+        self._apply_annotations_annotated(node, block)
+
     def _pass_read_annotations_early(self, node, chain):
         if isinstance(node, ast.Record):
             if node.ctype is not None:
@@ -215,6 +225,8 @@ class MainTransformer(object):
             self._apply_annotations_alias(node, chain)
         if isinstance(node, ast.Function):
             self._apply_annotations_function(node, chain)
+        if isinstance(node, ast.FunctionMacro):
+            self._apply_annotations_function_macro(node, chain)
         if isinstance(node, ast.Callback):
             self._apply_annotations_callable(node, chain, block=self._get_block(node))
         if isinstance(node, (ast.Class, ast.Interface, ast.Union, ast.Enum,
@@ -229,9 +241,7 @@ class MainTransformer(object):
             name = self._get_annotation_name(node)
             section_name = 'SECTION:%s' % (name.lower(), )
             block = self._blocks.get(section_name)
-            if block and block.description:
-                node.doc = block.description
-                node.doc_position = block.position
+            self._apply_annotations_annotated(node, block)
         if isinstance(node, (ast.Class, ast.Interface)):
             for prop in node.properties:
                 self._apply_annotations_property(node, prop)
@@ -659,11 +669,12 @@ class MainTransformer(object):
 
         if ANN_OPTIONAL in annotations:
             if (not isinstance(node, ast.Return) and
-                    node.direction == ast.PARAM_DIRECTION_OUT):
+                    node.direction in [ast.PARAM_DIRECTION_OUT,
+                                       ast.PARAM_DIRECTION_INOUT]):
                 node.optional = True
             else:
                 message.warn('invalid "optional" annotation: '
-                             'only valid for out parameters',
+                             'only valid for out and inout parameters',
                              annotations.position)
 
         if ANN_ALLOW_NONE in annotations:
